@@ -485,16 +485,22 @@ on_sync_menu_app_menu_path_changed (GObject * o, GParamSpec * ps, gpointer gentr
 
 static void
 on_sync_menu_app_vanished (GDBusConnection * connection  G_GNUC_UNUSED,
-                         const gchar     * dbus_name,
-                         gpointer          user_data)
+                           const gchar     * dbus_name_in,
+                           gpointer          user_data)
 {
   ClientEntry * entry;
   SyncService * self = user_data;
+  gchar * dbus_name;
+
+  /* service_remove_entry() calls g_bus_unwatch_name() which frees dbus_name_in.
+     Make a temporary copy of dbus_name_in to ensure we don't pass a dangling
+     pointer to entry_find_from_dbus_name()... */
+  dbus_name = g_strdup (dbus_name_in);
 
   while ((entry = entry_find_from_dbus_name (self, dbus_name)))
-   {
-     service_remove_entry (self, entry);
-   }
+    service_remove_entry (self, entry);
+
+  g_free (dbus_name);
 }
 
 static ClientEntry *
@@ -590,7 +596,7 @@ on_got_bus (GObject * o, GAsyncResult * res, gpointer user_data)
 
   if (err != NULL)
     {
-      g_error ("unable to get bus: %s", err->message);
+      g_warning ("unable to get bus: %s", err->message);
       g_clear_error (&err);
       g_main_loop_quit (sync_service.mainloop);
     }
@@ -611,7 +617,7 @@ on_got_bus (GObject * o, GAsyncResult * res, gpointer user_data)
 
       if (err != NULL)
         {
-          g_error ("unable to get bus: %s", err->message);
+          g_error ("unable to export service: %s", err->message);
           g_clear_error (&err);
         }
 
@@ -643,8 +649,6 @@ main (int argc, char ** argv)
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   textdomain (GETTEXT_PACKAGE);
 
-  g_type_init ();
-
   sync_service.skeleton = dbus_sync_service_skeleton_new ();
 
   g_bus_get (G_BUS_TYPE_SESSION, NULL, on_got_bus, &sync_service);
